package initialization

import (
	"time"

	"im-auth/middleware"
	"im-auth/pb"
	"im-auth/service/auth"
	"im-auth/service/health"

	"github.com/grpc-ecosystem/go-grpc-middleware"
	grpc_zap "github.com/grpc-ecosystem/go-grpc-middleware/logging/zap"
	grpc_recovery "github.com/grpc-ecosystem/go-grpc-middleware/recovery"
	grpc_validator "github.com/grpc-ecosystem/go-grpc-middleware/validator"
	"google.golang.org/grpc"
	"google.golang.org/grpc/keepalive"
	"google.golang.org/grpc/reflection"
)

var (
	RpcServer *grpc.Server
	kaep      = keepalive.EnforcementPolicy{
		MinTime:             5 * time.Second,
		PermitWithoutStream: true,
	}

	kasp = keepalive.ServerParameters{
		MaxConnectionIdle:     15 * time.Second,
		MaxConnectionAge:      30 * time.Second,
		MaxConnectionAgeGrace: 5 * time.Second,
		Time:                  5 * time.Second,
		Timeout:               1 * time.Second,
	}
)

func init() {

	rpc_server := grpc.NewServer(grpc.KeepaliveEnforcementPolicy(kaep), grpc.KeepaliveParams(kasp),
		grpc.UnaryInterceptor(grpc_middleware.ChainUnaryServer(
			middleware.Interceptor,
			grpc_validator.UnaryServerInterceptor(),
			grpc_recovery.UnaryServerInterceptor(middleware.RecoveryInterceptor()),
			grpc_zap.UnaryServerInterceptor(middleware.ZapInterceptor()),
		)))
	srv := health.NewServer()
	//pb.RegisterImUserServer(rpc_server, &im_user.ImUserServer{})
	pb.RegisterHealthServer(rpc_server, srv)
	pb.RegisterImAuthServiceServer(rpc_server, &auth.ImAuthServer{})

	reflection.Register(rpc_server)
	RpcServer = rpc_server

}
