package auth

import (
	"bytes"

	"im-auth/db"
	"im-auth/helper"
	"im-auth/pb"

	"google.golang.org/grpc/status"
)

const (
	tableName = "im_user"
)

//通过accid和appkey获取用户信息
func GetImUserByAccidAppkey(accid string, appkey string) (db.ImUser, error) {
	var c_user db.ImUser
	err := db.MysqlClient.QueryTable(tableName).Filter("accid", accid).Filter("appkey", appkey).One(&c_user)
	if err != nil {
		return c_user, err
	}
	return c_user, nil
}

func GetLogKey(in *pb.AuthRequest) string {
	var buffer bytes.Buffer
	buffer.WriteString(in.Accid)
	buffer.WriteString("_")
	buffer.WriteString(in.AppId)
	buffer.WriteString("_")
	buffer.WriteString(in.DeviceType)
	return buffer.String()
}

//登录处理
func LoginHandle(in *pb.AuthRequest) (int64, string) {
	fieldKey := GetLogKey(in)
	_, err := helper.GetRedis(fieldKey)
	if err == nil {
		return 417, "该种设备已经登录过了"
	}
	//写入redis
	loginTime := helper.GetNowTime()
	err = helper.SetRedis(fieldKey, loginTime)
	if err != nil {
		return 500, "写入redis失败"
	}
	return 0, "登录成功"
}

//退出处理
func LogoutHandle(in *pb.AuthRequest) error {
	fieldKey := GetLogKey(in)
	logStr, err := helper.GetRedis(fieldKey)
	if logStr == "" {
		err = status.Error(404, "没有登录信息")
		return err
	}
	err = helper.DelRedis(fieldKey)
	return err
}
